@@ -8,14 +8,14 @@
 #' @return quantile
 #'
 #' @examples
-#' data(soil_phylum_small)
-#' mod <- bbdml(formula = OTU.1 ~ DayAmdmt,
+#' data(soil_phylum_small_otu1)
+#' mod <- bbdml(formula = cbind(W, M - W) ~ DayAmdmt,
 #' phi.formula = ~ DayAmdmt,
-#' data = soil_phylum_small)
+#' data = soil_phylum_small_otu1)
 #' qbetabinom(.5, M = mod$M[1], mu = mod$mu.resp[1], phi = mod$phi.resp[1])
 #' @export
 qbetabinom <- function(p, M, mu, phi)  {
-  pdfvec <- VGAM::dbetabinom(x = 0:M, size = M, prob = mu, rho = phi)
+  pdfvec <- dbetabinom_cts(x = 0:M, size = M, prob = mu, rho = phi)
   # get cumulative probability
   CDF <- cumsum(pdfvec)
   # Find first value above quantile cutoff
